@@ -37,11 +37,13 @@ func TestTextSegment(t *testing.T) {
 		txt.Init(properties.Map{}, env)
 
 		template.Cache = &cache.Template{
-			UserName: "Posh",
-			HostName: "MyHost",
-			Shell:    "terminal",
-			Root:     true,
-			Folder:   "posh",
+			SimpleTemplate: cache.SimpleTemplate{
+				UserName: "Posh",
+				HostName: "MyHost",
+				Shell:    "terminal",
+				Root:     true,
+				Folder:   "posh",
+			},
 		}
 
 		assert.Equal(t, tc.ExpectedString, renderTemplate(env, tc.Template, txt), tc.Case)
